function [ u, s, blocks ] = BlockDiagSchurForm_AEgg2( Z, dim, eigBlockSep, tol)
    
%%  throw error if not 2D problem specified
    if dim ~= 2; disp('1D and 3D problems not supported');return; end

%%  Parameters
    nEigVal = size(Z, 1)/2;

%%  Perform real Schur factorization
    [u, s] = schur(Z);
    
%%  Block seperate eigenvalues
    eigVal = diag(s);
    
    singularNegID = abs(eigVal + tol < 0) & abs(eigVal - tol > -1);
    singularPosID = abs(eigVal + tol > 0) & abs(eigVal - tol <  1);
    negID         = eigVal < 0;
    posID         = eigVal > 0;
    zeroID        = abs(eigVal) < tol;
    
    if any(singularNegID)
        blocks = [nEigVal-2*dim,dim,2*dim,dim,nEigVal-2*dim];
        
        clusterID(posID)         = 1.*ones;
        clusterID(singularPosID) = 2.*ones;

        clusterID(negID)         = 5.*ones;
        clusterID(singularNegID) = 4.*ones;

        clusterID(zeroID)        = 3.*ones;
    else
        blocks = [nEigVal-dim,2*dim,nEigVal-dim];
        
        clusterID(posID)         = 1.*ones;
        clusterID(negID)         = 3.*ones;
        clusterID(zeroID)        = 2.*ones;
    end

    %block order Schur factorization based on sign of identified clusters
    [u, s] = ordschur(u,s,clusterID);
    
    %block-diagonalize Schur factorization
    [T, s] = bdschur(s, [], blocks);
        %accumulate transformations
        u = u*T; %accumulate transformation
        
%%  Correct rigid body modes
    u(1:      end, nEigVal-1:nEigVal) = zeros;
    u(1:2:nEigVal, nEigVal-1        ) = 1;
    u(2:2:nEigVal, nEigVal          ) = 1;
    
    s(nEigVal-1:nEigVal+2,nEigVal-1:nEigVal+2) = zeros;
    s(nEigVal+1:nEigVal+2,nEigVal+1:nEigVal+2) = eye(2);
    
end    
                 


