function [singularStressModes, angle, dist] = calcSingularStressModes(FEM,SD,elementID,eta)

    DOFPerElement = FEM.DOFPerNode * FEM.nodesPerElement;
    
    %find coordinates of the element in question
            [ xCoord , yCoord ] = elementNodeCoordinates( SD.nodes , SD.localElements , SD.extensionElement(elementID) , FEM.nodesPerElement, SD.SC);
        
        %find specific shape functions
            [shapeFunction , shapeFunctionDerivative] = shapeFunction1D (FEM.nodesPerElement , eta, FEM.quadratureType);
            numberOfShapeFunctions = length(shapeFunction);
            
        %coordinate transformations and their derivatives  
            x   = shapeFunction * xCoord;
            y   = shapeFunction * yCoord;
            x_n = shapeFunctionDerivative * xCoord;
            y_n = shapeFunctionDerivative * yCoord;
            
        %calculate specific jacobian and it's determinant
            detJ = x * y_n - y * x_n;
            
        %specify shape function for each DOF
            %initialize shape function and it's derivatives in 2D
                shapeFunction2D           = zeros( FEM.DOFPerNode , DOFPerElement );
                shapeFunctionDerivative2D = zeros( FEM.DOFPerNode , DOFPerElement );

            %construct shape functions and associated derivative=s in 2D
                positionCounter = 1;
                for k = 1:1:numberOfShapeFunctions
                    %abbreviation for simple notation
                    positionRow = 1:FEM.DOFPerNode;
                    positionCol = positionCounter : positionCounter + FEM.DOFPerNode - 1;

                    shapeFunction2D(positionRow,positionCol)           = shapeFunction(k)           * eye(2);
                    shapeFunctionDerivative2D(positionRow,positionCol) = shapeFunctionDerivative(k) * eye(2);
                    positionCounter = positionCounter + FEM.DOFPerNode;
                end
                
            %calculate strain desplacement matrices B1 B2
            B1 = 1/detJ * [y_n ,   0 ;...
                             0 , -x_n;...
                          -x_n ,  y_n] * shapeFunction2D;
            B2 = 1/detJ * [ -y ,   0 ;...
                             0 ,   x ;...
                             x ,  -y ] * shapeFunctionDerivative2D;
                
            %invariant subspace for specified element 
                elementDOF = SD.localElements(SD.extensionElement(elementID),:)';
                elementDOF = nodesToDOF(elementDOF(:),FEM.DOFPerNode);
        
                psi = SD.Q(elementDOF,:);
                
            %singular stress modes for specified element
                [ D ] = constitutiveMatrix2D( SD.E , SD.v , FEM.constitutiveLaw );
                psiSigma1_Schur = D * (-B1 * psi * SD.singularLambda(1) + B2 * psi);
                psiSigma2_Schur = D * (-B1 * psi * SD.singularLambda(2) + B2 * psi);

                singularStressModes = [psiSigma1_Schur(:,SD.singularInd(1));psiSigma2_Schur(:,SD.singularInd(2))];
                
                %starting node of element + eta factor of element length
                diffX = xCoord(end,:)- xCoord(1,:);
                diffY = yCoord(end,:)- yCoord(1,:);
                dx = xCoord(1,:) + (eta+1)/2*diffX;
                dy = yCoord(1,:) + (eta+1)/2*diffY;
                dist = sqrt(dx^2+dy^2);
                angle = atan(dy/dx);

end




















