function [SIFs_raw] = computeKRaw(FEM,SD)
        DOFPerElement = FEM.DOFPerNode * FEM.nodesPerElement;
        
        elementDOF = SD.localElements(SD.extensionElement(1),:)';
        elementDOF = nodesToDOF(elementDOF(:),FEM.DOFPerNode);
        
        psi = SD.Q(elementDOF,:);
            
        %find coordinates of the element in question
            [ xCoord , yCoord ] = elementNodeCoordinates( SD.nodes , SD.localElements , SD.patchElements(1) , FEM.nodesPerElement, SD.SC);

        %find specific shape functions
            [shapeFunction , shapeFunctionDerivative] = shapeFunction1D(FEM.nodesPerElement , SD.eta, FEM.quadratureType);
            
        %coordinate transformations and their derivatives  
            x   = shapeFunction * xCoord;
            y   = shapeFunction * yCoord;
            x_n = shapeFunctionDerivative * xCoord;
            y_n = shapeFunctionDerivative * yCoord;
            
        %calculate specific jacobian and it's determinant
            detJ = (x * y_n - y * x_n);
            
        %specify shape function for each DOF
            %initialize shape function and it's derivatives in 2D
                shapeFunction2D           = zeros( FEM.DOFPerNode , DOFPerElement );
                shapeFunctionDerivative2D = zeros( FEM.DOFPerNode , DOFPerElement );
                numberOfShapeFunctions = length(shapeFunction);
            %construct shape functions and associated derivatives in 2D
                positionCounter = 1;
                for k = 1:1:numberOfShapeFunctions
                    %abbreviation for simple notation
                    positionRow = 1:FEM.DOFPerNode;
                    positionCol = positionCounter : positionCounter + FEM.DOFPerNode - 1;

                    shapeFunction2D(positionRow,positionCol)           = shapeFunction(k)           * eye(2);
                    shapeFunctionDerivative2D(positionRow,positionCol) = shapeFunctionDerivative(k) * eye(2);
                    positionCounter = positionCounter + FEM.DOFPerNode;
                end
                
            %calculate strain desplacement matrices B1 B2
            B1 = 1/detJ * [y_n ,   0 ;...
                             0 , -x_n;...
                          -x_n ,  y_n] * shapeFunction2D;
            B2 = 1/detJ * [ -y ,   0 ;...
                             0 ,   x ;...
                             x ,  -y ] * shapeFunctionDerivative2D;

            [ D ] = constitutiveMatrix2D( SD.E , SD.v , FEM.constitutiveLaw );
            %singular stress modes for specified element
                psiSigma1 = D * (-B1 * psi * SD.singularLambda(1) + B2 * psi);
                psiSigma2 = D * (-B1 * psi * SD.singularLambda(2) + B2 * psi);
                
                %psiSigma1(:,SD.singularInd(1))
                %psiSigma2(:,SD.singularInd(2))
                %sqrt(2 * pi * SD.dist)
                %SD.singularC(1)
                %SD.singularC(2)
        %determine stress intensity factors
            %rotation
                c = cos(FEM.crackAngle);
                s = sin(FEM.crackAngle);
                rotation = [c^2,s^2,2*c*s;s^2,c^2,-2*s*c;-s*c, s*c,c^2-s^2];
                
            SIFs_raw = sqrt(2 * pi * SD.dist) * rotation * (psiSigma1(:,SD.singularInd(1)) * SD.singularC(1) + psiSigma2(:,SD.singularInd(2)) * SD.singularC(2));
            SIFs_raw = SIFs_raw(2:3)
end
















