function [SIFs] = computeSIFsRec(FEM,SD)
        [ samplingPoints , ~ ] = integrationParameters1D ( FEM.nodesPerElement , FEM.quadratureType);
        numberOfSamplingPoints = length(samplingPoints);
        singularStressModesStore = zeros(2*3,numberOfSamplingPoints*length(SD.extensionElement));

        for i = 1:1:length(SD.extensionElement)
            for j = 1:1:numberOfSamplingPoints
                [singularStressModes, angle, dist] = calcSingularStressModes(FEM,SD,i,samplingPoints(j));
                %rotate
                c = cos(angle); s = sin(angle); rotation = [c^2,s^2,2*c*s;s^2,c^2,-2*s*c;-s*c, s*c,c^2-s^2];
                singularStressModes(1:3,:) = rotation * singularStressModes(1:3,:);
                singularStressModes(4:6,:) = rotation * singularStressModes(4:6,:);
                %normalize to characteristic length
                singularStressModes(1:3,:) = singularStressModes(1:3,:) * (SD.L/dist)^(-SD.singularLambda(1)-1);
                singularStressModes(4:6,:) = singularStressModes(4:6,:) * (SD.L/dist)^(-SD.singularLambda(2)-1);
                %add to storing matrix
                singularStressModesStore(:,(i-1)*numberOfSamplingPoints+j) = singularStressModes;
            end
        end
            
    %smooth stress modes with least squares fit polynomial of same order as displacements
        xPoints = [samplingPoints, samplingPoints + 2];
        pBar = zeros(length(xPoints),numberOfSamplingPoints);

        for i= 1:1:length(xPoints)
            for j = 1:1:numberOfSamplingPoints
                pBar(i,j) = xPoints(1,i)^(j-1);
            end
        end

        A = ( pBar' * pBar ) \ pBar'; 
        P = [];
        for i = 1:1:numberOfSamplingPoints
            P = [P,SD.eta(1)^(i-1)];
        end

    %first singular mode
        %sigma_xx
        aM1 = A * singularStressModesStore(1,:)'; sigmaPM1XX = P * aM1;
        %sigma_yy
        aM1 = A * singularStressModesStore(2,:)'; sigmaPM1YY = P * aM1;
        %sigma_xy
        aM1 = A * singularStressModesStore(3,:)'; sigmaPM1XY = P * aM1;

    %second singular mode
        %sigma_xx
        aM2 = A * singularStressModesStore(4,:)'; sigmaPM2XX = P * aM2;
        %sigma_yy
        aM2 = A * singularStressModesStore(5,:)'; sigmaPM2YY = P * aM2;
        %sigma_xy
        aM2 = A * singularStressModesStore(6,:)'; sigmaPM2XY = P * aM2;

    %summation
        sigmaP = [sigmaPM1XX;sigmaPM1YY;sigmaPM1XY;sigmaPM2XX;sigmaPM2YY;sigmaPM2XY];

    SIFs_rec = sqrt(2 * pi * SD.L)*(sigmaP(1:3,:) * SD.singularC(1) + sigmaP(4:6,:) * SD.singularC(2));
    SIFs = SIFs_rec(2:3);

end












