function [extensionElement, eta, dist] = findExtensionElement(FEM,SD)
    %line
        %starting point
            %is the crack tip
        %slope
            slope = (SD.SC(2)-SD.nodes(1,2))/(SD.SC(1)-SD.nodes(1,1));
        %ending point
            extensionFactor = 1/FEM.tol;
            direction = sign(SD.SC(1)-SD.nodes(1,1));
            endPoint = [SD.SC(1)+extensionFactor*FEM.width*direction,SD.SC(2)+slope*extensionFactor*direction];
        %create line
            xLine=[SD.SC(1);endPoint(1)];
            yLine=[SD.SC(2);endPoint(2)];
    %box is boundary polygon
        xPGon = SD.bPolygon(:,1);
        yPGon = SD.bPolygon(:,2);
        
    %intersection
    [xI, yI] = polyxpoly(xLine, yLine, xPGon, yPGon);
    dist = sqrt((xI-SD.SC(1))^2+(yI-SD.SC(2))^2);
    
    %find nearest node
    distance = sqrt((xI-SD.nodes(:,1)).^2+(yI-SD.nodes(:,2)).^2);
    [~,ind] = min(distance);
    
    %find pertaining element
    [element,~]             = find(abs(SD.localElements-ind)<FEM.tol);
    [element,~] = sort(element,'ascend');
    
    extensionElement = element';
    
    %check amount of extension elements and correct patch if first or last element
    if length(extensionElement) == 1
        switch extensionElement
            case 1; extensionElement = [1,2];
            case SD.numberOfElements; extensionElement = [numberOfElements-1,numberOfElements];
            otherwise; extensionElement = [extensionElement,extensionElement+1];
        end
    end
       
    %determine eta as distance from first element node
    for i = 1:1:length(extensionElement)
        sNode = SD.localElements(extensionElement(i),1);
        distance = sqrt((xI-SD.nodes(sNode,1)).^2+(yI-SD.nodes(sNode,2)).^2);
        [ xCoord , yCoord ] = elementNodeCoordinates( SD.nodes , SD.localElements , extensionElement(i) , FEM.nodesPerElement, SD.SC);
        elementLength = sqrt((xCoord(1,:)-xCoord(end,:))^2 + (yCoord(1,:)-yCoord(end,:))^2);
        eta(i) = distance/elementLength*2-1;
    end
end