function[nodes, elements, elementsPerSide] = generateMesh_equalSpacing(FEM,SD)

%%  Parameters
    %Generate elements per side based on length and approximate element size
    elementsPerSide = [];

    numberOfSides = size(SD(1).bPolygon,1) - 1;
    
    nodes = [];

%%  Generate Nodes
    
    for i= 1:1:numberOfSides
        startingX = SD.bPolygon(i  ,1);
        endingX   = SD.bPolygon(i+1,1);
        startingY = SD.bPolygon(i  ,2);
        endingY   = SD.bPolygon(i+1,2);
        
        sideLength = sqrt((endingX-startingX)^2+(endingY-startingY)^2);
        
        sideElements = round(sideLength/SD.approxElementSize);
        
        elementsPerSide = [elementsPerSide,sideElements];
        
        nodesPerSide = ( FEM.nodesPerElement - 1 ) * elementsPerSide(1,i) + 1;
        
        nodesSideX = linspace( startingX, endingX, nodesPerSide)';
        nodesSideY = linspace( startingY, endingY, nodesPerSide)';
        nodesSideX(end,:) = [];
        nodesSideY(end,:) = [];
        
        nodes = [nodes; [nodesSideX, nodesSideY]];
        
    end
    
    %add and perturb last node, which is double crack node
    if SD.cracked == 1
        nodes = [nodes; SD.bPolygon(end,:)];
    end
    
    numberOfElements = sum(elementsPerSide);
    
    elements = zeros(numberOfElements, FEM.nodesPerElement);
    
    for i = 1:1:numberOfElements
        start = (i-1)*(FEM.nodesPerElement - 1) + 1;
        elements(i,:) = start: start + FEM.nodesPerElement - 1;
    end
    if SD.cracked == 0
        elements(end,end) = 1;
    end

end