function [BCDOF] = getBoundaryConditions(FEM,SD)
    %find all restrained points with FEM.nodes identifiers
    BCDOF = [];
    for i = 1:1:size(FEM.BCSide,1)
        switch(FEM.BCSide{i}{1})
            case 'r' %find right most nodes in domain
                points = find(abs(FEM.nodes(:,1)-max(FEM.nodes(:,1)))<FEM.tol);
                DOF    = nodesToDOF(points,FEM.DOFPerNode);
                if     FEM.BCSide{i}{2}(1) %x-direction restraint
                    BCDOF = [BCDOF,DOF(1:2:end)];
                end
                if FEM.BCSide{i}{2}(2) %y-direction restraint
                    BCDOF = [BCDOF,DOF(2:2:end)];
                end
            otherwise
                disp('BC case not implemented yet')
        end
    end
    for i = 1:1:size(FEM.BCPoint,2)
        switch(FEM.BCPoint{i}{1})
            case 'br' %find bottom right most node of domain
                points = find( (abs(FEM.nodes(:,1)-max(FEM.nodes(:,1)))<FEM.tol) & (abs(FEM.nodes(:,2)-min(FEM.nodes(:,2)))<FEM.tol) );
                DOF    = nodesToDOF(points,FEM.DOFPerNode);
                if     FEM.BCPoint{i}{2}(1) %x-direction restraint
                    BCDOF = [BCDOF,DOF(1:2:end)];
                end
                if FEM.BCPoint{i}{2}(2) %y-direction restraint 
                    BCDOF = [BCDOF,DOF(2:2:end)];
                end
            case 'bm' %find bottom middle node of domain
                points = find( (abs(FEM.nodes(:,2)-min(FEM.nodes(:,2)))<FEM.tol) & (abs(FEM.nodes(:,1)-FEM.width/2)<FEM.tol) );
                DOF    = nodesToDOF(points,FEM.DOFPerNode);
                if     FEM.BCPoint{i}{2}(1) %x-direction restraint
                    BCDOF = [BCDOF,DOF(1:2:end)];
                end
                if FEM.BCPoint{i}{2}(2) %y-direction restraint 
                    BCDOF = [BCDOF,DOF(2:2:end)];
                end
            case 'tm' %find top middle node of domain
                points = find( (abs(FEM.nodes(:,2)-max(FEM.nodes(:,2)))<FEM.tol) & (abs(FEM.nodes(:,1)-FEM.width/2)<FEM.tol) );
                DOF    = nodesToDOF(points,FEM.DOFPerNode);
                if     FEM.BCPoint{i}{2}(1) %x-direction restraint
                    BCDOF = [BCDOF,DOF(1:2:end)];
                end
                if FEM.BCPoint{i}{2}(2) %y-direction restraint 
                    BCDOF = [BCDOF,DOF(2:2:end)];
                end
            case 'tr' %find top right node of domain
                points = find( (abs(FEM.nodes(:,2)-max(FEM.nodes(:,2)))<FEM.tol) & abs(FEM.nodes(:,1)-max(FEM.nodes(:,1)))<FEM.tol );
                DOF    = nodesToDOF(points,FEM.DOFPerNode);
                if     FEM.BCPoint{i}{2}(1) %x-direction restraint
                    BCDOF = [BCDOF,DOF(1:2:end)];
                end
                if FEM.BCPoint{i}{2}(2) %y-direction restraint 
                    BCDOF = [BCDOF,DOF(2:2:end)];
                end
            otherwise
                disp('BC case not implemented yet')
        end
    end
    BCDOF = unique(BCDOF);
end