function [FEM,SD] = inputFile_6()
%%  "Pacman" geometry as reference for quadtree SIF calculation

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%  Input
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %working switches
    FEM.clear   = 1;    %1 = clc; 2 = clc, close all; 3 = clear all, close all, clc
    switch FEM.clear
        case 0  %do nothing
        case 1; clc;
        case 2; clc; close all;
        case 3; clear all; close all; clc;
    end
    FEM.verbose = 2;    %0 = no output; 1 = progress ouput; 2 = SIFs and nDOF ouput 
    FEM.timing  = 1;    %0 = no timings; 1 = all timings
    
    %plotting switches
    FEM.plotMesh          = 0;  %0 = no plot; 1 = plot
    FEM.plotDisplacements = 1;  %0 = no plot; 1 = plot
    
    %working switches
    if FEM.timing; FEM.tAnalysisStart = tic; end
    if FEM.verbose; fprintf(1,'Starting SBFEM analysis\n'); fprintf('******************************************\n');end
    if FEM.verbose; fprintf(1,' 1. Processing global input parameters...'); end

    %Analysis options
    FEM.elementSizeFactor = 1;                                          %modify
    FEM.nodesPerElement   = 2;                                          %modify
    FEM.quadratureType    = 1;      %1 = Gauss; 2 = Lobbatto
    FEM.constitutiveLaw   = 2;      %1 = plain strain; 2 = plain stress
    
    %Geometry and crack information
    FEM.width       = 1;
    FEM.height      = 1;
    FEM.crackLength = FEM.width/2; 
    FEM.crackAngle  = 0;                                           %modify
    FEM.crackMiddle = [0,FEM.height/2];
    
    %Load information
    FEM.load = 0.1;
    
    %Various other parameters
    FEM.DOFPerNode = 2;
    FEM.DOFPerElement   = FEM.DOFPerNode * FEM.nodesPerElement;
    
    FEM.tol = 10^-5; %changes manifest also in perturbing nodes!
    FEM.plotScalingFactor = 100;
    
    if FEM.verbose; fprintf('done!\n'); end
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%  Subdomains
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    if FEM.verbose; fprintf(1,' 2. Processing subdomains...'); end
    %alias
    w = FEM.width;
    h = FEM.height;

    %subdomain 1
    SD(1).SC = FEM.crackMiddle + FEM.crackLength .* [cos(FEM.crackAngle),sin(FEM.crackAngle)]; %scaling center || crack tip
    SD(1).E = 200;                  %E-modulus
    SD(1).v = 0.25;                 %Poisson ratio
    SD(1).L = 2*FEM.crackLength;    %characteristic crack length
    
    SD(1).bPolygon = [[0,h/2];[0,0];[w,0];[w,h];[0,h];[0,h/2]]; %define boundary polygon
    SD(1).bPolygon(1,2) = SD(1).bPolygon(1,2) + FEM.tol^3;              %Perturb double node
    
    SD(1).approxElementSize = FEM.width / FEM.elementSizeFactor;
    SD(1).cracked = 1;  %0 = no crack; 1 = crack

    if FEM.verbose; fprintf('done!\n'); end
    if FEM.verbose == 2; fprintf('\tnumber of subdomains = %d\n',length(SD)); end
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%  Loading
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    SD(1).FSide{1} = {'t',[0,1, FEM.load]}; % +load top    side of SD with load in y-direction
    SD(1).FSide{2} = {'b',[0,1,-FEM.load]}; % -load bottom side of SD with load in y-direction
    
    %SD(2).FSide{1} = {'t',[0,1, FEM.load]}; % +load top    side of SD with load in y-direction
    %SD(2).FSide{2} = {'b',[0,1,-FEM.load]}; % -load bottom side of SD with load in y-direction

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%  Boundary Conditions (as local nodes)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%    
    FEM.BCSide = [];
    
    FEM.BCPoint{1} = {'br',[1,1]}; %bottom-middle point is restrained in (x&y)-direction
    FEM.BCPoint{2} = {'tr',[1,0]}; %top-middle    point is restrained in (x)  -direction

end


















