function [shapeFunction , shapeFunctionDerivative] = shapeFunction1D (nodesPerElement , samplingPoint, quadratureType)
    n = samplingPoint;
    if quadratureType == 1 %Gauss
        switch nodesPerElement
            case(2) %2-node element
                shapeFunction = [ ( 1 - n ) / 2 , ( 1 + n ) / 2 ];

                shapeFunctionDerivative = [ - ( 1 / 2 ) , ( 1 / 2 ) ];

            case(3) %3-node element
                shapeFunction = [ n * ( n - 1 ) / 2 , ( 1 - n ) * ( 1 + n ) , n * ( n + 1 ) / 2 ];

                shapeFunctionDerivative = [ ( 2 * n - 1 ) / 2, - 2 * n, ( 2 * n + 1 ) / 2];

            case(4) %4-node element
                shapeFunction = [ ( 1 / 16 ) * ( 1 - n ) * ( 3 * n + 1 ) * ( 3 * n - 1 ) , ...
                                  ( 9 / 16 ) * ( 1 + n ) * (     n - 1 ) * ( 3 * n - 1 ) , ...
                                  ( 9 / 16 ) * ( 1 + n ) * (     1 - n ) * ( 3 * n + 1 ) , ...
                                  ( 1 / 16 ) * ( 1 + n ) * ( 3 * n + 1 ) * ( 3 * n - 1 ) ];

                shapeFunctionDerivative = [ ( - 27 * n ^ 2 + 18 * n +  1 ) / 16,...
                                            (   81 * n ^ 2 - 18 * n - 27 ) / 16,...
                                            ( - 81 * n ^ 2 - 18 * n + 27 ) / 16,...
                                            (   27 * n ^ 2 + 18 * n -  1 ) / 16];

            case(5) %5-node element
                shapeFunction = [ ( n * ( n - 1 ) * ( 2 * n - 1 ) * ( 2 * n + 1 ) ) / 6 ,...
                                - ( 4 * n * ( n - 1 ) * ( n + 1 ) * ( 2 * n - 1 ) ) / 3 ,...
                            ( n - 1 ) * ( n + 1 ) * ( 2 * n - 1 ) * ( 2 * n + 1 )       ,...
                                - ( 4 * n * ( n - 1 ) * ( n + 1 ) * ( 2 * n + 1 ) ) / 3 ,...
                                  ( n * ( n + 1 ) * ( 2 * n - 1 ) * ( 2 * n + 1 ) ) / 6 ];

                shapeFunctionDerivative = [ ( 16 * n ^ 3 - 12 * n ^ 2 - 2 * n + 1 ) / 6 ,...
                                         ( - 32 * n ^ 3 + 12 * n ^ 2 + 16 * n - 4 ) / 3 ,...
                                                                    16 * n ^ 3 - 10 * n ,...
                                         ( - 32 * n ^ 3 - 12 * n ^ 2 + 16 * n + 4 ) / 3 ,...
                                            ( 16 * n ^ 3 + 12 * n ^ 2 - 2 * n - 1 ) / 6 ];

            case(6) %6-node element
                    shapeFunction = [-((n-1)*(5*n-3)*(5*n-1)*(5*n+1)*(5*n+3))/768,...
                                     (25*(n-1)*(n+1)*(5*n-3)*(5*n-1)*(5*n+1))/768,...
                                    -(25*(n-1)*(n+1)*(5*n-3)*(5*n-1)*(5*n+3))/384,...
                                     (25*(n-1)*(n+1)*(5*n-3)*(5*n+1)*(5*n+3))/384,...
                                    -(25*(n-1)*(n+1)*(5*n-1)*(5*n+1)*(5*n+3))/768,...
                                      ((n+1)*(5*n-3)*(5*n-1)*(5*n+1)*(5*n+3))/768];

                    shapeFunctionDerivative = [(-3125*n^4+2500*n^3+750*n^2-500*n-9)/768,...
                                             (25*(625*n^4-300*n^3-390*n^2+156*n+5))/768,...
                                            -(25*(625*n^4-100*n^3-510*n^2+68*n+45))/384,...
                                             (25*(625*n^4+100*n^3-510*n^2-68*n+45))/384,...
                                            -(25*(625*n^4+300*n^3-390*n^2-156*n+5))/768,...
                                                (3125*n^4+2500*n^3-750*n^2-500*n+9)/768];
            otherwise
                disp('invalid shape function for specified amount of nodes per element')
        end
    elseif quadratureType == 2 %Lobatto
        switch nodesPerElement
        case 2
            shapeFunction(1,1)=0.5*(1-n);
            shapeFunction(1,2)=0.5*(1+n);
            shapeFunctionDerivative(1,1)=-0.5;
            shapeFunctionDerivative(1,2)=0.5;
        case 3
            shapeFunction(1,1)=0.5*(-1+n)*n;
            shapeFunction(1,2)=1-n*n;
            shapeFunction(1,3)=0.5*(1+n)*n;
            shapeFunctionDerivative(1,1)=-0.5+n;
            shapeFunctionDerivative(1,2)=-n-n;
            shapeFunctionDerivative(1,3)=0.5+n;
        case 4
            shapeFunction(1,1)=-0.125*(-1+n)*(-1+5*n*n);
            shapeFunction(1,2)= 0.625*(-1+n*n)*(-1+2.2360679774997897*n);
            shapeFunction(1,3)=-0.27950849718747371*(-1+n*n)*(2.2360679774997897+5*n);
            shapeFunction(1,4)= 0.125*( 1+n)*(-1+5*n*n);
            shapeFunctionDerivative(1,1)= 0.125*( 1+(10-15*n)*n);
            shapeFunctionDerivative(1,2)= 0.625*(-2.2360679774997897+(-2+6.7082039324993691*n)*n);
            shapeFunctionDerivative(1,3)=-0.279508497187473712*(-5+(4.472135954999579393+15*n)*n);
            shapeFunctionDerivative(1,4)= 0.125*(-1+(10+15*n)*n);
        case 5
            shapeFunction(1,1)= 0.125*n*( 3+(-3+(-7+7*n)*n)*n);
            shapeFunction(1,2)= 0.291666666666666667*n*(4.58257569495584001-7*n)*(-1+n*n);
            shapeFunction(1,3)= 0.333333333333333333*(3+(-10+7*n*n)*n*n);
            shapeFunction(1,4)=-0.291666666666666667*n*(4.58257569495584001+7*n)*(-1+n*n);
            shapeFunction(1,5)= 0.125*n*(-3+(-3+( 7+7*n)*n)*n);
            shapeFunctionDerivative(1,1)= 0.125*( 3+(-6+(-21+28*n)*n)*n);
            shapeFunctionDerivative(1,2)= 0.29166666666666667*(-4.58257569495584001+( 14+(13.74772708486752-28*n)*n)*n);
            shapeFunctionDerivative(1,3)= 1.333333333333333333*n*(-5+7*n*n);
            shapeFunctionDerivative(1,4)=-0.29166666666666667*(-4.58257569495584001+(-14+(13.74772708486752+28*n)*n)*n);
            shapeFunctionDerivative(1,5)= 0.125*(-3+(-6+( 21+28*n)*n)*n);
        case 6
            shapeFunction(1,1)= 0.0625+(-0.0625 +(-0.875+(0.875+(1.3125 -1.3125*n)*n)*n)*n)*n;
            shapeFunction(1,2)= -0.19464864235384228+(0.254424270069896506 +(2.58717294023997985 ...
                +(-3.38168085276733236+(-2.39252429788613758 +3.12725658269743585*n)*n)*n)*n)*n;
            shapeFunction(1,3)= 0.63214864235384228+(-2.21626505427473642 +(-1.71217294023997985 ...
                +(6.00274808816985155+(1.08002429788613758 -3.78648303389511513*n)*n)*n)*n)*n;
            shapeFunction(1,4)= 0.63214864235384228+( 2.21626505427473642 +(-1.71217294023997985 ...
                +(-6.00274808816985155+(1.08002429788613758 +3.78648303389511513*n)*n)*n)*n)*n;
            shapeFunction(1,5)= -0.19464864235384228+(-0.254424270069896506 +(2.58717294023997985 ...
                +( 3.38168085276733236+(-2.39252429788613758 -3.12725658269743585*n)*n)*n)*n)*n;
            shapeFunction(1,6)= 0.0625+( 0.0625 +(-0.875+(-0.875+(1.3125 +1.3125*n)*n)*n)*n)*n;
            shapeFunctionDerivative(1,1)= -0.0625+(-1.75 +( 2.625+(5.25 -6.5625*n)*n)*n)*n;
            shapeFunctionDerivative(1,2)= 0.254424270069896506+(5.17434588047995971 +(-10.1450425583019971+(-9.5700971915445503 +15.6362829134871793*n)*n)*n)*n;
            shapeFunctionDerivative(1,3)= -2.21626505427473642+(-3.42434588047995971 +( 18.0082442645095546+(4.3200971915445503 -18.9324151694755756*n)*n)*n)*n;
            shapeFunctionDerivative(1,4)=  2.21626505427473642+(-3.42434588047995971 +(-18.0082442645095546+(4.3200971915445503 +18.9324151694755756*n)*n)*n)*n;
            shapeFunctionDerivative(1,5)= -0.254424270069896506+(5.17434588047995971 +( 10.1450425583019971+(-9.5700971915445503 -15.6362829134871793*n)*n)*n)*n;
            shapeFunctionDerivative(1,6)=  0.0625+(-1.75 +(-2.625+(5.25 +6.5625*n)*n)*n)*n;
        end
    end
    
