function [FEM,SD] = inputFile_7()
%%  double edge crack modelled with single domain exploiting symmetry condition

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%  Input
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %working switches
    FEM.verbose = 2;
    FEM.clear   = 0;
    FEM.timing  = 1;
    
    %plotting switches
    FEM.plotMesh          = 1;
    FEM.plotDisplacements = 1;
    
    %working switches
    switch FEM.clear
        case 0  %do nothing
        case 1; clc;
        case 2; clc; close all;
        case 3; clear all; close all; clc;
    end
    if FEM.timing; FEM.tAnalysisStart = tic; end
    if FEM.verbose; fprintf(1,'Starting SBFEM analysis\n'); fprintf('******************************************\n');end
    if FEM.verbose; fprintf(1,' 1. Processing global input parameters...'); end

    %Analysis options
    FEM.elementSizeFactor = 0.5;                          %MODIFIED
    FEM.nodesPerElement   = 2;                            %MODIFIED
    FEM.quadratureType    = 1;
    FEM.constitutiveLaw   = 2;
    
    %Geometry and crack information
    FEM.width       = 1;
    FEM.height      = 1;
    
    %Load information
    FEM.load = 0.1;
    
    %Various other parameters
    FEM.DOFPerNode = 2;
    FEM.DOFPerElement   = FEM.DOFPerNode * FEM.nodesPerElement;
    
    FEM.tol = 10^-5; %changes manifest also in mesher!
    FEM.plotScalingFactor = 250;
    
    if FEM.verbose; fprintf('done!\n'); end
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%  Subdomains
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    if FEM.verbose; fprintf(1,' 2. Processing subdomains...'); end

    %Scaling center 1
    SD(1).SC = [2,2];
    SD(1).E = 200;
    SD(1).v = 0.3;
    
    SD(1).bPolygon = [1,0;3,0;3,3;0,3;0,1;0.3827,0.9239;0.7071,0.7071;0.9239,0.3827;1,0];
    
    SD(1).approxElementSize = FEM.elementSizeFactor;
    SD(1).cracked = 0;
    SD(1).correctEPS = 1;
    
    if FEM.verbose; fprintf('done!\n'); end
    if FEM.verbose == 2; fprintf('\tnumber of subdomains = %d\n',length(SD)); end
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%  Loading
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    SD(1).FSide{1} = {'t',[0,1, FEM.load]}; % load top side of SD with load in y-direction
    SD(1).FSide{2} = {'b',[0,1,-FEM.load]}; % load top side of SD with load in y-direction

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%  Boundary Conditions (as local nodes)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    FEM.BCSide{1}  = {'r' ,[1,0]}; %right side of domain is restrained in x-direction
    FEM.BCPoint{1} = {'br',[1,1]}; %bottom-right point is restrained in x&y-direction

end